@@ -8,7 +8,7 @@ from .auth.authorizers import TokenStore, RefreshTokenAuth, OAuthTokenAuth
 from .auth import DeviceCodeAuth, OAuthClientParams, PersonalAccessTokenAuth
 from .client import (
     PublisherClient,
-    DataConnectClient,
+    DataConnectClientV2,
     CollectionsClient,
     WesClient,
     BaseServiceClient,
