@@ -1,5 +1,6 @@
 from dnastack.client import *
 from ...utils import catch_errors, get_client
+from ....client.base_exceptions import ApiError
 from ....exceptions import ServiceException
 import json
 import click
@@ -13,11 +14,6 @@ def tables():
 @tables.command("list")
 @click.pass_context
 @click.argument("collection_name")
-@catch_errors((ServiceException,))
+@catch_errors((ApiError, ServiceException,))
 def list_tables(ctx: click.Context, collection_name: str):
-    click.echo(
-        json.dumps(
-            get_client(ctx).collections.list_tables(collection_name),
-            indent=4,
-        )
-    )
+    click.echo(json.dumps(get_client(ctx).collections.list_tables(collection_name), indent=4))
