@@ -1,5 +1,8 @@
+from click import Abort
+
 from dnastack.client import *
 from ...utils import catch_errors, get_client
+from ....client.base_exceptions import ApiError
 from ....exceptions import ServiceException
 import json
 import click
@@ -12,19 +15,27 @@ def tables():
 
 @tables.command("list")
 @click.pass_context
-@catch_errors((ServiceException,))
+@catch_errors((ApiError, ServiceException,))
 def list_tables(ctx: click.Context):
-    click.echo(json.dumps(list(get_client(ctx).dataconnect.list_tables()), indent=4))
+    click.echo(
+        json.dumps(
+            [
+                t.dict()
+                for t in get_client(ctx).dataconnect.list_tables()
+            ],
+            indent=4
+        )
+    )
 
 
 @tables.command("get")
 @click.pass_context
 @click.argument("table_name")
-@catch_errors((ServiceException,))
+@catch_errors((ApiError, ServiceException,))
 def get(ctx: click.Context, table_name):
     click.echo(
         json.dumps(
-            get_client(ctx).dataconnect.get_table(table_name),
+            get_client(ctx).dataconnect.get_table(table_name).dict(),
             indent=4,
         )
     )
