@@ -1,23 +1,32 @@
-from dnastack.cli.utils import get_config
+from typing import List
 from dnastack.client import *
-from dnastack.client.files_client import download_files
+from ..utils import catch_errors, get_client
+from ...exceptions import ServiceException, DRSDownloadException
+import click
+import os
 
 
 @click.group()
-@click.pass_context
-def files(ctx):
+def files():
     pass
 
 
-@files.command()
+@files.command("download")
 @click.pass_context
 @click.argument("urls", required=False, nargs=-1)
 @click.option(
-    "-o", "--output-dir", required=False, default=downloads_directory, show_default=True
+    "-o", "--output-dir", required=False, default=os.getcwd(), show_default=True
 )
 @click.option("-i", "--input-file", required=False, default=None)
-@click.option("-q", "--quiet", is_flag=True, required=False)
-def download(ctx, urls, output_dir, input_file, quiet):
+@click.option("-q", "--quiet", is_flag=True, required=False, default=False)
+@catch_errors((ServiceException, DRSDownloadException))
+def download(
+    ctx: click.Context,
+    urls: List[str],
+    output_dir: str = os.getcwd(),
+    input_file: str = None,
+    quiet: bool = False,
+):
     download_urls = []
 
     if len(urls) > 0:
@@ -41,10 +50,6 @@ def download(ctx, urls, output_dir, input_file, quiet):
                 break
 
             download_urls.append(url)
-    try:
-        download_files(download_urls, output_dir, quiet=quiet)
-    except Exception as e:
-        click.secho(
-            f"Unable to execute downloads for urls [{','.join(urls)}]: {e}", fg="red"
-        )
-        sys.exit(1)
+    get_client(ctx).download(
+        urls=download_urls, output_dir=output_dir, display_progress_bar=(not quiet)
+    )
