@@ -1,12 +1,12 @@
 import os
+from typing import Union, List, Any, AnyStr
 
 from requests.auth import AuthBase
+
 from . import *
-from typing import Union, List, Any, AnyStr
 from .base_client import BaseServiceClient
 from ..auth import OAuthTokenAuth
 from ..constants import DEFAULT_SERVICE_REGISTRY
-from ..exceptions import ServiceTypeNotFoundError
 
 
 class PublisherClient:
@@ -32,13 +32,9 @@ class PublisherClient:
 
         if dataconnect_url:
             if isinstance(self.auth, OAuthTokenAuth):
-                self.__dataconnect = DataConnectClient(
-                    url=dataconnect_url, auth=self.auth, registry_url=registry_url
-                )
+                self.__dataconnect = DataConnectClientV2(url=dataconnect_url, auth=self.auth, registry_url=registry_url)
             else:
-                self.__dataconnect = DataConnectClient(
-                    url=dataconnect_url, auth=None, registry_url=registry_url
-                )
+                self.__dataconnect = DataConnectClientV2(url=dataconnect_url, auth=None, registry_url=registry_url)
 
         if collections_url:
             self.__collections = CollectionsClient(
@@ -54,12 +50,12 @@ class PublisherClient:
             self.__files = FilesClient(None)
 
     @property
-    def dataconnect(self) -> DataConnectClient:
+    def dataconnect(self) -> DataConnectClientV2:
         return self.__dataconnect
 
     @dataconnect.setter
-    def dataconnect(self, client: DataConnectClient):
-        assert client is None or isinstance(client, DataConnectClient)
+    def dataconnect(self, client: DataConnectClientV2):
+        assert client is None or isinstance(client, DataConnectClientV2)
         self.__dataconnect = client
 
     @property
