@@ -14,9 +14,9 @@ class TestCliWesCommand(BaseCliTestCase):
     def setUpCLI(self):
         self.wes_url = TEST_WES_URI
 
-        self.setConfig("wes.url", self.wes_url)
-        self.useOAuthClient("wes", TEST_OAUTH_CLIENTS["wes"])
-        self.useRefreshToken("wes", TEST_WALLET_REFRESH_TOKEN["wes"])
+        self.set_config("wes.url", self.wes_url)
+        self.define_oauth_client("wes", TEST_OAUTH_CLIENTS["wes"])
+        self.define_refresh_token("wes", TEST_WALLET_REFRESH_TOKEN["wes"])
 
     def test_wes_info_with_auth(self):
         result_objects = self.assertCommand(["wes", "info"], json_output=True)
